=============
Django Statsd
=============

This is a friendly fork with support for Django>1.8,<1.12.

The original documentation is on `Read the Docs <https://django-statsd.readthedocs.org/>`_.

-------
License
-------

BSD and MPL

Portions of this are from commonware:

https://github.com/jsocol/commonware/blob/master/LICENSE
